@@ -19,34 +19,42 @@ import os
 """
 Return the data pretty printed as a string.
 """
-def to_string (data, tabwidth=0, min_padding=2, separator='_'):
-	printer = DataPrinter(tabwidth=tabwidth,
-	                      min_padding=min_padding,
-	                      separator=separator)
-	return printer.string_output(data)
-
-def to_newfile (filename, data, tabwidth=0, min_padding=2, separator='_',
-                overwrite=False):
+def to_string (data, tabwidth=0, min_padding=2, separator='_', columns=False):
 	printer = DataPrinter(tabwidth=tabwidth,
 	                      min_padding=min_padding,
 	                      separator=separator,
-	                      overwrite=overwrite)
-	printer.new_file_output(filename=filename, data=data)
+	                      columns=columns)
+	return printer.string_output(data)
 
-def to_file (open_file, data, tabwidth=0, min_padding=2, separator='_'):
+def to_newfile (filename, data, tabwidth=0, min_padding=2, separator='_',
+                overwrite=False, columns=False):
 	printer = DataPrinter(tabwidth=tabwidth,
 	                      min_padding=min_padding,
-	                      separator=separator)
+	                      separator=separator,
+	                      overwrite=overwrite,
+	                      columns=columns)
+	printer.new_file_output(filename=filename, data=data)
+
+def to_file (open_file, data, tabwidth=0, min_padding=2, separator='_',
+             columns=False):
+	printer = DataPrinter(tabwidth=tabwidth,
+	                      min_padding=min_padding,
+	                      separator=separator,
+	                      columns=columns)
 	printer.append_file_output(fd=open_file, data=data)
 
 
+MISSING_STRING = "MISSING"
+
+
 class DataPrinter:
 	def __init__ (self, tabwidth=0, min_padding=2, separator='_',
-	              overwrite=False):
+	              overwrite=False, columns=False):
 		self._tabwidth  = int(tabwidth)
 		self._padding   = int(min_padding)
 		self._separator = str(separator)
 		self._overwrite = bool(overwrite)
+		self._columns   = bool(columns)
 
 		if self._tabwidth < 0 or self._padding < 0:
 			raise DataPrinterException("Invalid padding or tabwidth.")
@@ -88,40 +96,76 @@ to True in order to overwrite the file.")
 		except AttributeError:
 			raise DataPrinterException("Data is not a valid format.")
 
-		num_columns = [max(len(str(x)) for x in line) for line in zip(*data)][0]
+		if self._columns:
+			# Data is formated such that each list in data contains all the
+			# values for a column of data
+			num_cols = len(data)
+			num_rows = [max(len(x) for x in data)][0]
+		else:
+			num_cols = [max(len(x) for x in data)][0]
+			num_rows = len(data)
 
-		# assume we have a list of lists
-		max_lens = [0] * num_columns
+		# Assume we have a list of lists
+		max_lens = [0] * num_cols
 
-		# get the maximum len of each column
-		for row in data:
-			for i, col in zip(range(len(row)), row):
-				col_str = str(col)
+		# Get the maximum len of each column
+		for i, array in zip(range(len(data)), data):
+			for j, item in zip(range(len(array)), array):
 				# Determine the len of the data item after separators are used
-				col_str = self._separator.join(str(col).split())
+				item_str = self._separator.join(str(item).split())
 
-				if len(col_str) > max_lens[i]:
-					max_lens[i] = len(col_str)
+				column_index = i if self._columns else j
 
-		for row in data:
-			for i, col in zip(range(len(row)), row):
-				col_str = self._separator.join(str(col).split())
+				if len(item_str) > max_lens[column_index]:
+					max_lens[column_index] = len(item_str)
 
-				if i == len(row) - 1:
-					# Don't add padding to the end of the last column
-					outfile.write("{0}\n".format(col_str))
-					continue
+		# Update the max lens if we have column data.
+		# Need to compensate if one column is longer than another.
+		if self._columns:
+			for i in range(num_cols):
+				if len(data[i]) < num_rows:
+					if len(MISSING_STRING) > max_lens[i]:
+						max_lens[i] = len(MISSING_STRING)
 
-				if self._tabwidth == 0:
-					# use spaces
-					outfile.write("{1:<{0}s}".format(max_lens[i]+ self._padding,
-					                                 col_str));
-				else:
-					max_line = max_lens[i] + self._padding
-					max_line_tabs = ((max_line - 1) // self._tabwidth) + 1
-					tabs = max_line_tabs - (len(str(col)) // self._tabwidth)
-					outfile.write("{1:\t<{0}s}".format(tabs + len(col_str),
-					                                   col_str));
+		# Iterate and write the output data
+		if self._columns:
+			# Iterate over the length the longest column
+			for row_idx in range(num_rows):
+				for col_idx in range(num_cols):
+					if row_idx < len(data[col_idx]):
+						istr = self._separator.join(
+							str(data[col_idx][row_idx]).split())
+					else:
+						istr = MISSING_STRING
+
+					pad = (col_idx != num_cols - 1)
+
+					self.write_to_output(outfile, istr, pad, max_lens[col_idx])
+
+		else:
+			for row_idx, row in zip(range(len(data)), data):
+				for col_idx, item in zip(range(len(row)), row):
+					istr = self._separator.join(str(item).split())
+
+					pad = (col_idx != len(row) - 1)
+
+					self.write_to_output(outfile, istr, pad, max_lens[col_idx])
+
+
+	def write_to_output (self, outfile, item, padding, max_len):
+		if not padding:
+			# Don't add padding to the end of the last column
+			outfile.write("{0}\n".format(item))
+			return
+
+		if self._tabwidth == 0:
+			# use spaces
+			outfile.write("{1:<{0}s}".format(max_len+ self._padding, item));
+		else:
+			max_line = max_len + self._padding
+			max_line_tabs = ((max_line - 1) // self._tabwidth) + 1
+			tabs = max_line_tabs - (len(str(item)) // self._tabwidth)
+			outfile.write("{1:\t<{0}s}".format(tabs + len(item), item));
 
 
 class StringFile:
